@@ -33,6 +33,14 @@ impl<TVar: Variable, CVar: Variable> TypecheckState<TVar, CVar> {
         self
     }
 
+    /// Binds a list of variables.
+    pub fn bind_vars(mut self, binds: List<(Symbol, Type<TVar, CVar>)>) -> Self {
+        for (s,t) in binds.into_iter() {
+            self.variable_scope.insert(s, t);
+        }
+        self
+    }
+
     /// Binds a const-generic variable.
     pub fn bind_cgvar(mut self, s: Symbol, v: ConstExpr<CVar>) -> Self {
         self.cg_scope.insert(s, v);
@@ -82,6 +90,10 @@ impl<TVar: Variable, CVar: Variable> TypecheckState<TVar, CVar> {
         self.function_scope.get(&name).cloned()
     }
 
+    pub fn var_scope(&self) -> Map<Symbol, Type<TVar, CVar>> {
+        self.variable_scope.clone()
+    }
+
     /// Applies some type facts
     pub fn with_facts(mut self, facts: &TypeFacts<TVar, CVar>) -> Self {
         log::trace!("with facts {:?}", facts);
